#!/usr/bin/env python
# coding=utf-8

import argparse
import os
import subprocess
import sys

import black
import glob2

PEP8_MAXLINE = 79
VERSION = "0.6.1"


def get_parser():
    """
    解析命令行参数
    """
    parser = argparse.ArgumentParser(
        description="Format code via command line with `black`"
    )
    parser.add_argument(
        "paths",
        metavar="PATHS",
        type=str,
        nargs="*",
        help="Files and directories that should be executed format command.",
    )
    parser.add_argument(
        "-l",
        "--line",
        type=int,
        default=PEP8_MAXLINE,
        help="How many character per line to allow.[default: 79]",
    )
    parser.add_argument(
        "-sp",
        "--settings_path",
        type=str,
        default="",
        help="`isort` Explicitly set the settings path instead of auto "
        "determining based on file location",
    )
    parser.add_argument(
        "-v",
        "--version",
        action="store_true",
        help="Displays the current version of pink",
    )
    return parser


def command_line_runner():
    """
    主函数
    """
    python = sys.executable
    black_exec = black.__file__.rstrip("cdo")

    parser = get_parser()
    args = vars(parser.parse_args())
    if args["version"]:
        print(VERSION)
        return

    paths = args["paths"]
    if not paths:
        parser.print_help()
        return

    settings = args["settings_path"]
    sp_cmd = ""
    if settings:
        sp_cmd = f" -sp {os.path.abspath(settings)}"

    maxline = args["line"]

    cnt = 0
    print("🎉✨  Formatting code...")
    for path in paths:
        for file in glob2.glob(path):
            cnt += 1
            subprocess.Popen(
                f"isort {file}" + sp_cmd,
                stdout=subprocess.PIPE,
                stderr=subprocess.STDOUT,
            )
        # 写在同一循环内 black 操作执行有误
        for file in glob2.glob(path):
            subprocess.Popen(
                f"{python} {black_exec} {file} --line-length {maxline}",
                stdout=subprocess.PIPE,
                stderr=subprocess.STDOUT,
            )
    print("✨🎉  All {} files done!".format(cnt))
    sys.exit()


if __name__ == "__main__":
    command_line_runner()
